@@ -1,6 +1,6 @@
 from django.conf import settings
 from django.contrib import admin
-from models import TwitterAccount, TwitterStatus
+from twittersync.models import TwitterAccount, TwitterStatus
 
 
 class TwitterAccountAdmin(admin.ModelAdmin):
